@@ -38,10 +38,11 @@ THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #ifndef __dyn_generic_h__
 #define __dyn_generic_h__
 
+#include <stdbool.h>
 #include "wintypes.h"
 
 	LONG DYN_LoadLibrary(void **, char *);
 	LONG DYN_CloseLibrary(void **);
-	LONG DYN_GetAddress(void *, /*@out@*/ void **, const char *, int);
+	LONG DYN_GetAddress(void *, /*@out@*/ void **, const char *, bool);
 
 #endif
