@@ -751,9 +751,9 @@ static void HPDeviceNotificationThread(void)
  * matching devices.
  * Adds or removes matching readers as necessary.
  */
-LONG HPSearchHotPluggables(void)
+LONG HPSearchHotPluggables(const char * hpDirPath)
 {
-	Drivers = HPDriversGetFromDirectory(PCSCLITE_HP_DROPDIR);
+	Drivers = HPDriversGetFromDirectory(hpDirPath);
 
 	if (!Drivers)
 		return 1;
@@ -775,14 +775,14 @@ static int HPScan(void)
 
 	for (a = devices; a; a = a->m_next)
 	{
-		int found = FALSE;
+		bool found = false;
 		HPDevice *b;
 
 		for (b = sDeviceList; b; b = b->m_next)
 		{
 			if (HPDeviceEquals(a, b))
 			{
-				found = TRUE;
+				found = true;
 				break;
 			}
 		}
@@ -803,14 +803,14 @@ static int HPScan(void)
 
 	for (a = sDeviceList; a; a = a->m_next)
 	{
-		int found = FALSE;
+		bool found = false;
 		HPDevice *b;
 
 		for (b = devices; b; b = b->m_next)
 		{
 			if (HPDeviceEquals(a, b))
 			{
-				found = TRUE;
+				found = true;
 				break;
 			}
 		}
@@ -834,7 +834,7 @@ pthread_t sHotplugWatcherThread;
 /*
  * Sets up callbacks for device hotplug events.
  */
-ULONG HPRegisterForHotplugEvents(void)
+ULONG HPRegisterForHotplugEvents(const char * hpDirPath)
 {
 	ThreadCreate(&sHotplugWatcherThread,
 		THREAD_ATTR_DEFAULT,
